# V2

Types:

```python
from nimbleway_webit.types import V2MapResponse
```

Methods:

- <code title="post /map">client.v2.<a href="./src/nimbleway_webit/resources/v2/v2.py">map</a>(\*\*<a href="src/nimbleway_webit/types/v2_map_params.py">params</a>) -> <a href="./src/nimbleway_webit/types/v2_map_response.py">V2MapResponse</a></code>

## Crawl

Types:

```python
from nimbleway_webit.types.v2 import (
    CrawlListResponse,
    CrawlCancelResponse,
    CrawlCrawlResponse,
    CrawlGetResponse,
)
```

Methods:

- <code title="get /crawl">client.v2.crawl.<a href="./src/nimbleway_webit/resources/v2/crawl.py">list</a>(\*\*<a href="src/nimbleway_webit/types/v2/crawl_list_params.py">params</a>) -> <a href="./src/nimbleway_webit/types/v2/crawl_list_response.py">SyncCrawlPagination[CrawlListResponse]</a></code>
- <code title="delete /crawl/{id}">client.v2.crawl.<a href="./src/nimbleway_webit/resources/v2/crawl.py">cancel</a>(id) -> <a href="./src/nimbleway_webit/types/v2/crawl_cancel_response.py">CrawlCancelResponse</a></code>
- <code title="post /crawl">client.v2.crawl.<a href="./src/nimbleway_webit/resources/v2/crawl.py">crawl</a>(\*\*<a href="src/nimbleway_webit/types/v2/crawl_crawl_params.py">params</a>) -> <a href="./src/nimbleway_webit/types/v2/crawl_crawl_response.py">CrawlCrawlResponse</a></code>
- <code title="get /crawl/{id}">client.v2.crawl.<a href="./src/nimbleway_webit/resources/v2/crawl.py">get</a>(id) -> <a href="./src/nimbleway_webit/types/v2/crawl_get_response.py">CrawlGetResponse</a></code>

## Agent

Types:

```python
from nimbleway_webit.types.v2 import AgentAsyncResponse, AgentGetResponse
```

Methods:

- <code title="post /agent/async">client.v2.agent.<a href="./src/nimbleway_webit/resources/v2/agent.py">async\_</a>(\*\*<a href="src/nimbleway_webit/types/v2/agent_async_params.py">params</a>) -> <a href="./src/nimbleway_webit/types/v2/agent_async_response.py">AgentAsyncResponse</a></code>
- <code title="post /agent">client.v2.agent.<a href="./src/nimbleway_webit/resources/v2/agent.py">get</a>(\*\*<a href="src/nimbleway_webit/types/v2/agent_get_params.py">params</a>) -> <a href="./src/nimbleway_webit/types/v2/agent_get_response.py">AgentGetResponse</a></code>

## Extract

Types:

```python
from nimbleway_webit.types.v2 import (
    ExtractAsyncResponse,
    ExtractBatchResponse,
    ExtractExtractResponse,
)
```

Methods:

- <code title="post /extract/async">client.v2.extract.<a href="./src/nimbleway_webit/resources/v2/extract.py">async\_</a>(\*\*<a href="src/nimbleway_webit/types/v2/extract_async_params.py">params</a>) -> <a href="./src/nimbleway_webit/types/v2/extract_async_response.py">ExtractAsyncResponse</a></code>
- <code title="post /extract/batch">client.v2.extract.<a href="./src/nimbleway_webit/resources/v2/extract.py">batch</a>(\*\*<a href="src/nimbleway_webit/types/v2/extract_batch_params.py">params</a>) -> <a href="./src/nimbleway_webit/types/v2/extract_batch_response.py">ExtractBatchResponse</a></code>
- <code title="post /extract">client.v2.extract.<a href="./src/nimbleway_webit/resources/v2/extract.py">extract</a>(\*\*<a href="src/nimbleway_webit/types/v2/extract_extract_params.py">params</a>) -> <a href="./src/nimbleway_webit/types/v2/extract_extract_response.py">ExtractExtractResponse</a></code>

## Tasks

Types:

```python
from nimbleway_webit.types.v2 import TaskListResponse, TaskGetResponse, TaskResultsResponse
```

Methods:

- <code title="get /tasks">client.v2.tasks.<a href="./src/nimbleway_webit/resources/v2/tasks.py">list</a>(\*\*<a href="src/nimbleway_webit/types/v2/task_list_params.py">params</a>) -> <a href="./src/nimbleway_webit/types/v2/task_list_response.py">SyncCrawlPagination[TaskListResponse]</a></code>
- <code title="get /tasks/{task_id}">client.v2.tasks.<a href="./src/nimbleway_webit/resources/v2/tasks.py">get</a>(task_id) -> <a href="./src/nimbleway_webit/types/v2/task_get_response.py">TaskGetResponse</a></code>
- <code title="get /tasks/{task_id}/results">client.v2.tasks.<a href="./src/nimbleway_webit/resources/v2/tasks.py">results</a>(task_id) -> <a href="./src/nimbleway_webit/types/v2/task_results_response.py">TaskResultsResponse</a></code>

## Batches

Types:

```python
from nimbleway_webit.types.v2 import BatchGetResponse, BatchProgressResponse
```

Methods:

- <code title="get /batches">client.v2.batches.<a href="./src/nimbleway_webit/resources/v2/batches.py">list</a>() -> None</code>
- <code title="get /batches/{batch_id}">client.v2.batches.<a href="./src/nimbleway_webit/resources/v2/batches.py">get</a>(batch_id) -> <a href="./src/nimbleway_webit/types/v2/batch_get_response.py">BatchGetResponse</a></code>
- <code title="get /batches/{batch_id}/progress">client.v2.batches.<a href="./src/nimbleway_webit/resources/v2/batches.py">progress</a>(batch_id) -> <a href="./src/nimbleway_webit/types/v2/batch_progress_response.py">BatchProgressResponse</a></code>
